/**
 * @license Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

CKEDITOR.plugins.setLang( 'codesnippet', 'he', {
	button: 'הכנס קטע קוד',
	codeContents: 'תוכן קוד',
	emptySnippetError: 'קטע קוד לא יכול להיות ריק.',
	language: 'שפה',
	title: 'קטע קוד',
	pathName: 'code snippet' // MISSING
} );
