/**
 * @license Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

CKEDITOR.plugins.setLang( 'codesnippet', 'ca', {
	button: 'Insereix el fragment de codi',
	codeContents: 'Contingut del codi',
	emptySnippetError: 'El fragment de codi no pot estar buit.',
	language: 'Idioma',
	title: 'Fragment de codi',
	pathName: 'fragment de codi'
} );
