CKEDITOR.plugins.setLang('youtube', 'de', {
	button : 'YouTube Video einbinden',
	title : 'YouTube Video einbinden',
	txtEmbed : 'Embed Code hier einfügen',
	txtUrl : 'YouTube Video URL hier einfügen',
	txtWidth : 'Breite',
	txtHeight : 'Höhe',
	chkRelated : 'Vorschläge am Ende des Videos einblenden',
	txtStartAt : 'Start bei Position (ss oder mm:ss oder hh:mm:ss)',
	chkPrivacy : 'Erweiterten Datenschutzmodus aktivieren',
	chkOlderCode : 'Benutze alten Embed Code',
	chkAutoplay : 'Autoplay',
	chkControls : 'Player-Steuerelemente anzeigen',
	noCode : 'Sie müssen einen Embed Code oder URL angeben',
	invalidEmbed : 'Der angegebene Embed Code scheint nicht gültig zu sein.',
	invalidUrl : 'Die angegebene URL scheint nicht gültig zu sein.',
	or : 'oder',
	noWidth : 'Geben Sie eine Breite an',
	invalidWidth : 'Geben Sie eine gültige Breite an',
	noHeight : 'Geben Sie eine Höhe an',
	invalidHeight : 'Geben Sie eine gültige Höhe an',
	invalidTime : 'Geben Sie eine gültige Startzeit an',
	txtResponsive : 'Automatische Größe (ignoriert Breite und Höhe)'
});
