/**
 * @license Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

CKEDITOR.plugins.setLang( 'codesnippet', 'el', {
	button: 'Εισαγωγή Αποσπάσματος Κώδικα',
	codeContents: 'Περιεχόμενο κώδικα',
	emptySnippetError: 'Δεν γίνεται να είναι κενά τα αποσπάσματα κώδικα.',
	language: 'Γλώσσα',
	title: 'Απόσπασμα κώδικα',
	pathName: 'απόσπασμα κώδικα'
} );
