/**
 * @license Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

CKEDITOR.plugins.setLang( 'codesnippet', 'oc', {
	button: 'Inserir un extrait de còdi',
	codeContents: 'Còdi',
	emptySnippetError: 'Un extrait de còdi pòt pas èsser void.',
	language: 'Lenga',
	title: 'Extrait de còdi',
	pathName: 'extrait de còdi'
} );
