/**
 * @license Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

CKEDITOR.plugins.setLang( 'codesnippet', 'ja', {
	button: 'コードスニペットを挿入',
	codeContents: 'コード内容',
	emptySnippetError: 'コードスニペットを入力してください。',
	language: '言語',
	title: 'コードスニペット',
	pathName: 'コードスニペット'
} );
